ReadFieldResult

Enum ReadFieldResult 

pub enum ReadFieldResult {
    InputEmpty,
    OutputFull,
    Field {
        record_end: bool,
    },
    End,
}
The result of parsing at most one field from CSV data.

Variants



InputEmpty

The caller provided input was exhausted before the end of a field or record was found.



OutputFull

The caller provided output buffer was filled before an entire field could be written to it.



Field

The end of a field was found.

Note that when record_end is true, then the end of this field also corresponds to the end of a record.

Fields

record_end: bool

Whether this was the last field in a record or not.



End

All CSV data has been read.

This state can only be returned when an empty input buffer is provided by the caller.